@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2013 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -329,6 +329,7 @@ class document():
         """Get HTML report."""
         
         mzFormat = '%0.' + `config.main['mzDigits']` + 'f'
+        intFormat = '%0.' + `config.main['intDigits']` + 'f'
         ppmFormat = '%0.' + `config.main['ppmDigits']` + 'f'
         
         # add header
@@ -395,15 +396,17 @@ class document():
             buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 1);" title="Sort by">Calc.&nbsp;m/z</a></th>\n'
             buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 2);" title="Sort by">&delta;&nbsp;(Da)</a></th>\n'
             buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 3);" title="Sort by">&delta;&nbsp;(ppm)</a></th>\n'
-            buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 4);" title="Sort by">Rel.&nbsp;Int.&nbsp;(%)</a></th>\n'
-            buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 5);" title="Sort by">z</a></th>\n'
-            buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 6);" title="Sort by">Annotation</a></th>\n'
-            buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 7);" title="Sort by">Formula</a></th>\n'
+            buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 4);" title="Sort by">Int.</a></th>\n'
+            buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 5);" title="Sort by">Rel.&nbsp;Int.&nbsp;(%)</a></th>\n'
+            buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 6);" title="Sort by">z</a></th>\n'
+            buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 7);" title="Sort by">Annotation</a></th>\n'
+            buff += '        <th><a href="" onclick="return sortTable(\''+tableID+'\', 8);" title="Sort by">Formula</a></th>\n'
             buff += '      </tr>\n'
             buff += '    </thead>\n'
             buff += '    <tbody id="%s">\n' % tableID
             for annot in self.annotations:
                 mz = mzFormat % annot.mz
+                absIntensity = intFormat % (annot.ai - annot.base)
                 relIntensity = ''
                 theoretical = ''
                 charge = ''
@@ -425,7 +428,7 @@ class document():
                 if annot.radical:
                     charge = str(annot.charge) + ' &bull;'
                 
-                buff += '      <tr><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="center nowrap">%s</td><td>%s</td><td class="nowrap">%s</td></tr>\n' % (mz, theoretical, deltaDa, deltaPpm, relIntensity, charge, label, formula)
+                buff += '      <tr><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="right nowrap">%s</td><td class="center nowrap">%s</td><td>%s</td><td class="nowrap">%s</td></tr>\n' % (mz, theoretical, deltaDa, deltaPpm, absIntensity, relIntensity, charge, label, formula)
             buff += '    </tbody>\n'
             buff += '  </table>\n'
         
