@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2013 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -549,6 +549,7 @@ compounds = {}
 
 mascot = {
     'Matrix Science':{
+            'protocol': 'http',
             'host': 'www.matrixscience.com',
             'path': '/',
             'search': 'cgi/nph-mascot.exe',
@@ -743,6 +744,7 @@ def loadMascot(path=os.path.join(config.confdir, 'mascot.xml'), clear=True, repl
         for serverTag in serverTags:
             name = serverTag.getAttribute('name')
             container[name] = {
+                'protocol': 'http',
                 'host': '',
                 'path': '/',
                 'search': 'cgi/nph-mascot.exe',
@@ -961,6 +963,7 @@ def saveMascot(path=os.path.join(config.confdir, 'mascot.xml')):
     
     for name in sorted(mascot.keys()):
         buff += '   <server name="%s">\n' % (_escape(name))
+        buff += '     <param name="protocol" value="%s" type="unicode" />\n' % (_escape(mascot[name]['protocol']))
         buff += '     <param name="host" value="%s" type="unicode" />\n' % (_escape(mascot[name]['host']))
         buff += '     <param name="path" value="%s" type="unicode" />\n' % (_escape(mascot[name]['path']))
         buff += '     <param name="search" value="%s" type="unicode" />\n' % (_escape(mascot[name]['search']))
