@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2013 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -234,7 +234,7 @@ class panelDocumentExport(wx.MiniFrame):
         self.peaklistSelect_choice.Select(0)
         
         peaklistFormat_label = wx.StaticText(panel, -1, "Format:")
-        self.peaklistFormat_choice = wx.Choice(panel, -1, choices=['ASCII', 'MGF'], size=(200, mwx.CHOICE_HEIGHT))
+        self.peaklistFormat_choice = wx.Choice(panel, -1, choices=['ASCII', 'ASCII with Headers', 'MGF'], size=(200, mwx.CHOICE_HEIGHT))
         self.peaklistFormat_choice.SetStringSelection(config.export['peaklistFormat'])
         self.peaklistFormat_choice.Bind(wx.EVT_CHOICE, self.onPeaklistFormatChanged)
         
@@ -536,7 +536,7 @@ class panelDocumentExport(wx.MiniFrame):
         """Export peeaklist data."""
         
         # get format
-        if config.export['peaklistFormat'] == 'ASCII':
+        if config.export['peaklistFormat'] in ('ASCII' 'ASCII with Headers'):
             fileName = 'peaklist.txt'
             fileType = "ASCII file|*.txt"
         elif config.export['peaklistFormat'] == 'MGF':
@@ -725,15 +725,44 @@ class panelDocumentExport(wx.MiniFrame):
             return
         
         # export to ascii
-        if config.export['peaklistFormat'] == 'ASCII':
+        if config.export['peaklistFormat'] in ('ASCII', 'ASCII with Headers'):
+            
+            buff = ''
             
             # set separator
             separator = config.export['peaklistSeparator']
             if config.export['peaklistSeparator'] == 'tab':
                 separator = '\t'
             
+            # export headers
+            if config.export['peaklistFormat'] == 'ASCII with Headers':
+                header = ''
+                if 'mz' in config.export['peaklistColumns']:
+                    header += "m/z" + separator
+                if 'ai' in config.export['peaklistColumns']:
+                    header += "a.i." + separator
+                if 'base' in config.export['peaklistColumns']:
+                    header += "base" + separator
+                if 'int' in config.export['peaklistColumns']:
+                    header += "int" + separator
+                if 'rel' in config.export['peaklistColumns']:
+                    header += "r.int." + separator
+                if 'sn' in config.export['peaklistColumns']:
+                    header += "s/n" + separator
+                if 'z' in config.export['peaklistColumns']:
+                    header += "z" + separator
+                if 'mass' in config.export['peaklistColumns']:
+                    header += "mass" + separator
+                if 'fwhm' in config.export['peaklistColumns']:
+                    header += "fwhm" + separator
+                if 'resol' in config.export['peaklistColumns']:
+                    header += "resol." + separator
+                if 'group' in config.export['peaklistColumns']:
+                    header += "group" + separator
+                
+                buff += '%s\n' % (header.rstrip())
+            
             # export data
-            buff = ''
             for peak in peaklist:
                 line = ''
                 if 'mz' in config.export['peaklistColumns']:
@@ -758,7 +787,8 @@ class panelDocumentExport(wx.MiniFrame):
                     line += str(peak.resolution) + separator
                 if 'group' in config.export['peaklistColumns']:
                     line += str(peak.group) + separator
-                buff += '%s\n' % (line.rstrip())
+                
+                buff += '%s\n' % (line.replace("None","").rstrip())
         
         # export to mgf
         elif config.export['peaklistFormat'] == 'MGF':
