@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2013 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -1517,7 +1517,7 @@ class panelMascot(wx.MiniFrame):
         
         # make search path
         name = config.mascot['common']['server']
-        script = 'http://'+libs.mascot[name]['host']+libs.mascot[name]['path']+libs.mascot[name]['search']+'?1'
+        script = libs.mascot[name]['protocol']+'://'+libs.mascot[name]['host']+libs.mascot[name]['path']+libs.mascot[name]['search']+'?1'
         
         # make html page
         buff = '<?xml version="1.0" encoding="utf-8"?>\n'
