@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2013 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -764,7 +764,7 @@ class panelMassToFormula(wx.MiniFrame):
                 
                 # compare isotopic pattern
                 similarity = None
-                if config.massToFormula['checkPattern']:
+                if config.massToFormula['checkPattern'] and cmpd.isvalid(charge=config.massToFormula['charge'], agentFormula=config.massToFormula['ionization']):
                     similarity = self.compareIsotopicPattern(cmpd, config.massToFormula['charge'], config.massToFormula['ionization'], errorDa)
                 
                 # count ratios
