@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2013 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -881,6 +881,9 @@ class panelPeaklist(wx.Panel):
             mz = float(mz)
             ai = float(ai)
             
+            if ai == 0:
+                raise ValueError
+            
             if base:
                 base = float(base)
             else:
