@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2013 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -820,9 +820,11 @@ class panelProspector(wx.MiniFrame):
                 'All',
                 'HUMAN MOUSE',
                 'HUMAN RODENT',
+                'MODEL PLANTS',
                 'RODENT',
                 'ROACH LOCUST BEETLE',
                 'MICROORGANISMS',
+                'ARABIDOPSIS',
                 'ARABIDOPSIS THALIANA',
                 'ARCHAEOGLOBUS FULGIDUS',
                 'BACILLUS SUBTILIS',
@@ -855,11 +857,10 @@ class panelProspector(wx.MiniFrame):
                 'HELICOBACTER PYLORI',
                 'HOMO SAPIENS',
                 'HORDEUM',
-                'MODEL PLANTS',
+                'HUMAN ADENOVIRUS 5',
                 'MACACA',
                 'MAMMALS',
                 'METHANOCOCCUS JANNASCHII',
-                'HUMAN ADENOVIRUS 5',
                 'MUS MUSCULUS',
                 'MYCOBACTERIUM',
                 'MYCOPLASMA',
@@ -899,6 +900,7 @@ class panelProspector(wx.MiniFrame):
                 'V8 DE',
                 'V8 E',
                 'Lys-C',
+                'Lys-C-Pro',
                 'Lys-N',
                 'Arg-C',
                 'Asp-N',
@@ -909,11 +911,14 @@ class panelProspector(wx.MiniFrame):
                 'Glu-C',
                 'Tyr-C',
                 'Thermolysin',
+                'Elastase',
                 'Full Protein',
                 'Pro-C',
+                'Pro-N',
                 'Proteinase K',
                 'Rhizopuspepsin',
                 'Cys-N',
+                'KR-N',
                 'CNBr/Trypsin',
                 'CNBr/V8 DE',
                 'CNBr/V8 E',
@@ -937,9 +942,15 @@ class panelProspector(wx.MiniFrame):
                 'Lys-C/V8 E',
                 'Lys-C/Asp-N',
                 'Lys-C/DE-N',
+                'Lys-C/Glu-C',
                 'V8 DE/Chymotrypsin',
                 'Arg-C/V8 E',
                 'Glu-C/Asp-N',
+                'DE-N/Cys-N',
+                'Asp-N/Asp-C',
+                'Asp-C/Cys-N',
+                'Lys-C/Lys-N',
+                'Trypsin/KR-N',
             ],
             'fixedMods':[
                 'Acetohydrazide (C-term)',
@@ -948,26 +959,41 @@ class panelProspector(wx.MiniFrame):
                 'Acetyl (N-term)',
                 'Acetyl:2H(3) (K)',
                 'Acetyl:2H(3) (N-term)',
+                'Acetyl:2H(3)+Methyl (K)',
+                'ADP-Ribosyl (CEKNSR)',
+                'ADP-Ribosyl (E)',
+                'ADP-Ribosyl (K)',
+                'ADP-Ribosyl (R)',
                 'Amidated (C-term)',
                 'Amidated+iTRAQ8plex (C-term)',
                 'Amino (Y)',
-                'Asn->Succinimide (N)',
+                'Ammonia-loss (K)',
+                'Ammonia-loss (R)',
+                'AMTzGalNAcGlcNAc (N)',
+                'AMTzGalNAcGlcNAc (ST)',
+                'APTA (C)',
+                'Asn-&gt;Succinimide (N)',
                 'Biotin (N-term)',
                 'Carbamidomethyl (C)',
                 'Carbamidomethyl (N-term)',
                 'Carbamyl (K)',
                 'Carbamyl (N-term)',
+                'Carboxy (E)',
                 'Carboxy (W)',
                 'Carboxymethyl (C)',
+                'Cation:Na (C-term)',
+                'Cation:Na (DE)',
                 'Cyano (C)',
-                'Cys->Dha (C)',
+                'Cys-&gt;Dha (C)',
                 'Deamidated (N)',
                 'Deamidated (Q)',
+                'Dehydrated (C-term)',
                 'Dehydrated (D)',
                 'Dehydrated (ST)',
                 'Dehydro (C)',
                 'Delta:2H(6)C(3) (K)',
                 'Delta:2H(6)C(3) (N-term)',
+                'Delta:H(2)C(2) (N-term)',
                 'Delta:H(2)C(3) (K)',
                 'Delta:H(4)C(3)O(1) (C)',
                 'Delta:H(4)C(3)O(1) (CHK)',
@@ -977,24 +1003,35 @@ class panelProspector(wx.MiniFrame):
                 'Delta:H(6)C(6)O(1) (K)',
                 'Delta:H(8)C(6)O(2) (K)',
                 'Dethiomethyl (M)',
+                'Didehydro (C)',
                 'Dimethyl (N-term)',
+                'Dioxidation (C)',
                 'Dioxidation (M)',
                 'Dioxidation (W)',
                 'DTT_C (C)',
                 'DTT_C:2H(6) (C)',
                 'DTT_ST (ST)',
                 'DTT_ST:2H(6) (ST)',
+                'Ethanolyl (C)',
                 'Formyl (K)',
                 'Formyl (N-term)',
+                'Formyl (ST)',
                 'GirardT (N)',
                 'GlyGly (C)',
                 'GlyGly (N-term)',
                 'GlyTyr (N-term)',
                 'Guanidinyl (K)',
+                'HexNAc (N)',
                 'HexNAc (ST)',
+                'HexNAc (Y)',
                 'HexNAcHex (ST)',
                 'HexNAcHexSA (ST)',
+                'HexNAcHexSA2 (ST)',
+                'HexNAcHexSAOx (ST)',
+                'HexNACHExSAOxSAOx (ST)',
+                'HexNACHexSASAOx (ST)',
                 'HexNAcSA (ST)',
+                'HexNAcSAOx (ST)',
                 'Hydroxymethyl (CRWHKNQY)',
                 'ICAT-C (C)',
                 'ICAT-C:13C(9) (C)',
@@ -1006,6 +1043,7 @@ class panelProspector(wx.MiniFrame):
                 'iTRAQ4plex (Y)',
                 'iTRAQ8plex (K)',
                 'iTRAQ8plex (N-term)',
+                'iTRAQ8plex (Y)',
                 'Label:13C(6) (K)',
                 'Label:13C(6) (L)',
                 'Label:13C(6) (R)',
@@ -1013,7 +1051,29 @@ class panelProspector(wx.MiniFrame):
                 'Label:13C(6)15N(2) (K)',
                 'Label:13C(6)15N(2)+Carbamyl (K)',
                 'Label:13C(6)15N(4) (R)',
+                'Label:15N(1) (A)',
+                'Label:15N(1) (C)',
+                'Label:15N(1) (D)',
+                'Label:15N(1) (E)',
+                'Label:15N(1) (F)',
+                'Label:15N(1) (G)',
+                'Label:15N(1) (I)',
+                'Label:15N(1) (L)',
+                'Label:15N(1) (M)',
+                'Label:15N(1) (P)',
+                'Label:15N(1) (S)',
+                'Label:15N(1) (T)',
+                'Label:15N(1) (V)',
+                'Label:15N(1) (Y)',
+                'Label:15N(1)+Carbamidomethyl (C)',
+                'Label:15N(1)+Deamidated (N)',
+                'Label:15N(1)+Oxidation (M)',
                 'Label:15N(2) (K)',
+                'Label:15N(2) (N)',
+                'Label:15N(2) (Q)',
+                'Label:15N(2) (W)',
+                'Label:15N(3) (H)',
+                'Label:15N(4) (R)',
                 'Label:18O(1) (C-term)',
                 'Label:18O(2) (C-term)',
                 'Label:2H(3) (L)',
@@ -1027,8 +1087,10 @@ class panelProspector(wx.MiniFrame):
                 'Methyl:13C(1)2H(3) (DE)',
                 'Methylthiol (C)',
                 'Nethylmaleimide (C)',
+                'Nethylmaleimide+water (C)',
                 'NIPCAM (C)',
                 'Nitro (Y)',
+                'Nitrosyl (C)',
                 'Oxidation (M)',
                 'Oxidation (P)',
                 'Oxidation (PWY)',
@@ -1038,6 +1100,9 @@ class panelProspector(wx.MiniFrame):
                 'Phospho (ST)',
                 'Phospho (STY)',
                 'Phospho (Y)',
+                'PhosphoHexNAc (ST)',
+                'Piperidine (K)',
+                'Piperidine (N-term)',
                 'Propionamide (C)',
                 'Pyridylethyl (C)',
                 'Quinone (W)',
@@ -1045,20 +1110,29 @@ class panelProspector(wx.MiniFrame):
                 'SerTyr+iTRAQ (N-term)',
                 'SerTyrLys(OAc) (N-term)',
                 'SerTyrLys(OAcs) (N-term)',
+                'Sulfide (C)',
                 'Sulfo (Y)',
+                'Thiophospho (ST)',
                 'TMT (K)',
                 'TMT (N-term)',
+                'TMT (Y)',
                 'TMT2plex (K)',
                 'TMT2plex (N-term)',
+                'TMT2plex (Y)',
                 'TMT6plex (K)',
                 'TMT6plex (N-term)',
+                'TMT6plex (Y)',
                 'Trioxidation (C)',
-                'Trp->Hydroxykynurenin (W)',
-                'Trp->Kynurenin (W)',
+                'Trp-&gt;Hydroxykynurenin (W)',
+                'Trp-&gt;Kynurenin (W)',
                 'Xlink:BSSA1 (N-term)',
                 'Xlink:BSSA2 (N-term)',
                 'Xlink:DSS1 (N-term)',
+                'Xlink:DSS1:2H(12) (N-term)',
+                'Xlink:DSS1:2H(4) (N-term)',
                 'Xlink:DSS2 (N-term)',
+                'Xlink:DSS2:2H(12) (N-term)',
+                'Xlink:DSS2:2H(4) (N-term)',
                 'Xlink:FCXL1-1 (N-term)',
                 'Xlink:FCXL1-2 (N-term)',
             ],
@@ -1066,34 +1140,44 @@ class panelProspector(wx.MiniFrame):
                 'Acetohydrazide (C-term)',
                 'Acetohydrazide (DE)',
                 'Acetyl (K)',
-                'Acetyl (Protein N-term)',
-                'Acetyl+Oxidation (Protein N-term M)',
+                'Acetyl (N-term)',
                 'Acetyl:2H(3) (K)',
                 'Acetyl:2H(3) (N-term)',
+                'Acetyl:2H(3)+Methyl (K)',
+                'ADP-Ribosyl (CEKNSR)',
+                'ADP-Ribosyl (E)',
+                'ADP-Ribosyl (K)',
+                'ADP-Ribosyl (R)',
                 'Amidated (C-term)',
                 'Amidated+iTRAQ8plex (C-term)',
                 'Amino (Y)',
-                'Asn->Succinimide (N)',
+                'Ammonia-loss (K)',
+                'Ammonia-loss (R)',
+                'AMTzGalNAcGlcNAc (N)',
+                'AMTzGalNAcGlcNAc (ST)',
+                'APTA (C)',
+                'Asn-&gt;Succinimide (N)',
                 'Biotin (N-term)',
-                'Biotin (Uncleaved K)',
                 'Carbamidomethyl (C)',
                 'Carbamidomethyl (N-term)',
-                'Carbamidomethyl (Uncleaved DEHKM)',
-                'Carbamidomethyl (Uncleaved HKM)',
                 'Carbamyl (K)',
                 'Carbamyl (N-term)',
+                'Carboxy (E)',
                 'Carboxy (W)',
                 'Carboxymethyl (C)',
-                'Cation:N(1)H(4) (Neutral loss)',
+                'Cation:Na (C-term)',
+                'Cation:Na (DE)',
                 'Cyano (C)',
-                'Cys->Dha (C)',
+                'Cys-&gt;Dha (C)',
                 'Deamidated (N)',
                 'Deamidated (Q)',
+                'Dehydrated (C-term)',
                 'Dehydrated (D)',
                 'Dehydrated (ST)',
                 'Dehydro (C)',
                 'Delta:2H(6)C(3) (K)',
                 'Delta:2H(6)C(3) (N-term)',
+                'Delta:H(2)C(2) (N-term)',
                 'Delta:H(2)C(3) (K)',
                 'Delta:H(4)C(3)O(1) (C)',
                 'Delta:H(4)C(3)O(1) (CHK)',
@@ -1103,34 +1187,35 @@ class panelProspector(wx.MiniFrame):
                 'Delta:H(6)C(6)O(1) (K)',
                 'Delta:H(8)C(6)O(2) (K)',
                 'Dethiomethyl (M)',
+                'Didehydro (C)',
                 'Dimethyl (N-term)',
-                'Dimethyl (Uncleaved K)',
-                'Dimethyl (Uncleaved R)',
+                'Dioxidation (C)',
                 'Dioxidation (M)',
                 'Dioxidation (W)',
-                'Disuccinyl (Uncleaved K)',
                 'DTT_C (C)',
                 'DTT_C:2H(6) (C)',
                 'DTT_ST (ST)',
                 'DTT_ST:2H(6) (ST)',
+                'Ethanolyl (C)',
                 'Formyl (K)',
                 'Formyl (N-term)',
+                'Formyl (ST)',
                 'GirardT (N)',
-                'Gln->pyro-Glu (N-term Q)',
-                'Glu->pyro-Glu (N-term E)',
-                'GluGlnIleGlyGly (Uncleaved K)',
                 'GlyGly (C)',
                 'GlyGly (N-term)',
-                'GlyGly (Uncleaved K)',
                 'GlyTyr (N-term)',
                 'Guanidinyl (K)',
+                'HexNAc (N)',
                 'HexNAc (ST)',
+                'HexNAc (Y)',
                 'HexNAcHex (ST)',
                 'HexNAcHexSA (ST)',
+                'HexNAcHexSA2 (ST)',
+                'HexNAcHexSAOx (ST)',
+                'HexNACHExSAOxSAOx (ST)',
+                'HexNACHexSASAOx (ST)',
                 'HexNAcSA (ST)',
-                'HNE (Uncleaved CHKPRT)',
-                'HNE+Delta:H(2) (Uncleaved CHKPRT)',
-                'HNE-Delta:H(2)O (Uncleaved CHKPRT)',
+                'HexNAcSAOx (ST)',
                 'Hydroxymethyl (CRWHKNQY)',
                 'ICAT-C (C)',
                 'ICAT-C:13C(9) (C)',
@@ -1142,25 +1227,40 @@ class panelProspector(wx.MiniFrame):
                 'iTRAQ4plex (Y)',
                 'iTRAQ8plex (K)',
                 'iTRAQ8plex (N-term)',
+                'iTRAQ8plex (Y)',
                 'Label:13C(6) (K)',
                 'Label:13C(6) (L)',
                 'Label:13C(6) (R)',
-                'Label:13C(6)+GlyGly (Uncleaved K)',
                 'Label:13C(6)15N(1) (L)',
                 'Label:13C(6)15N(2) (K)',
                 'Label:13C(6)15N(2)+Carbamyl (K)',
-                'Label:13C(6)15N(2)+GluGlnIleGlyGly (Uncleaved K)',
-                'Label:13C(6)15N(2)+GlyGly (Uncleaved K)',
                 'Label:13C(6)15N(4) (R)',
+                'Label:15N(1) (A)',
+                'Label:15N(1) (C)',
+                'Label:15N(1) (D)',
+                'Label:15N(1) (E)',
+                'Label:15N(1) (F)',
+                'Label:15N(1) (G)',
+                'Label:15N(1) (I)',
+                'Label:15N(1) (L)',
+                'Label:15N(1) (M)',
+                'Label:15N(1) (P)',
+                'Label:15N(1) (S)',
+                'Label:15N(1) (T)',
+                'Label:15N(1) (V)',
+                'Label:15N(1) (Y)',
+                'Label:15N(1)+Carbamidomethyl (C)',
+                'Label:15N(1)+Deamidated (N)',
+                'Label:15N(1)+Oxidation (M)',
                 'Label:15N(2) (K)',
+                'Label:15N(2) (N)',
+                'Label:15N(2) (Q)',
+                'Label:15N(2) (W)',
+                'Label:15N(3) (H)',
+                'Label:15N(4) (R)',
                 'Label:18O(1) (C-term)',
                 'Label:18O(2) (C-term)',
                 'Label:2H(3) (L)',
-                'LeuArgGlyGly (Uncleaved K)',
-                'Met->Hsl (C-term M)',
-                'Met-loss (Protein N-term M)',
-                'Met-loss+Acetyl (Protein N-term M)',
-                'Met-loss+Myristoyl (Protein N-term M)',
                 'Methyl (C-term)',
                 'Methyl (DE)',
                 'Methyl (E)',
@@ -1170,12 +1270,11 @@ class panelProspector(wx.MiniFrame):
                 'Methyl:13C(1)2H(3) (C-term)',
                 'Methyl:13C(1)2H(3) (DE)',
                 'Methylthiol (C)',
-                'Myristoyl (N-term G)',
-                'Myristoyl (Uncleaved KR)',
                 'Nethylmaleimide (C)',
-                'NHS-LC-Biotin (Uncleaved K)',
+                'Nethylmaleimide+water (C)',
                 'NIPCAM (C)',
                 'Nitro (Y)',
+                'Nitrosyl (C)',
                 'Oxidation (M)',
                 'Oxidation (P)',
                 'Oxidation (PWY)',
@@ -1185,44 +1284,45 @@ class panelProspector(wx.MiniFrame):
                 'Phospho (ST)',
                 'Phospho (STY)',
                 'Phospho (Y)',
+                'PhosphoHexNAc (ST)',
+                'Piperidine (K)',
+                'Piperidine (N-term)',
                 'Propionamide (C)',
-                'PyridoxalPhosphate (Uncleaved K)',
                 'Pyridylethyl (C)',
                 'Quinone (W)',
                 'SerTyr (N-term)',
                 'SerTyr+iTRAQ (N-term)',
                 'SerTyrLys(OAc) (N-term)',
                 'SerTyrLys(OAcs) (N-term)',
-                'Succinyl (Uncleaved K)',
+                'Sulfide (C)',
                 'Sulfo (Y)',
+                'Thiophospho (ST)',
                 'TMT (K)',
                 'TMT (N-term)',
+                'TMT (Y)',
                 'TMT2plex (K)',
                 'TMT2plex (N-term)',
+                'TMT2plex (Y)',
                 'TMT6plex (K)',
                 'TMT6plex (N-term)',
-                'TriMethyl (Uncleaved K)',
+                'TMT6plex (Y)',
                 'Trioxidation (C)',
-                'Trisuccinyl (Uncleaved K)',
-                'Trp->Hydroxykynurenin (W)',
-                'Trp->Kynurenin (W)',
-                'Xlink:BSSA1 (Protein N-term)',
-                'Xlink:BSSA1 (Uncleaved K)',
-                'Xlink:BSSA2 (Protein N-term)',
-                'Xlink:BSSA2 (Uncleaved K)',
-                'Xlink:DSA1 (Uncleaved K)',
-                'Xlink:DSA2 (Uncleaved K)',
-                'Xlink:DSS1 (Protein N-term)',
-                'Xlink:DSS1 (Uncleaved K)',
-                'Xlink:DSS2 (Protein N-term)',
-                'Xlink:DSS2 (Uncleaved K)',
-                'Xlink:FCXL1-1 (Protein N-term)',
-                'Xlink:FCXL1-1 (Uncleaved K)',
-                'Xlink:FCXL1-2 (Protein N-term)',
-                'Xlink:FCXL1-2 (Uncleaved K)',
+                'Trp-&gt;Hydroxykynurenin (W)',
+                'Trp-&gt;Kynurenin (W)',
+                'Xlink:BSSA1 (N-term)',
+                'Xlink:BSSA2 (N-term)',
+                'Xlink:DSS1 (N-term)',
+                'Xlink:DSS1:2H(12) (N-term)',
+                'Xlink:DSS1:2H(4) (N-term)',
+                'Xlink:DSS2 (N-term)',
+                'Xlink:DSS2:2H(12) (N-term)',
+                'Xlink:DSS2:2H(4) (N-term)',
+                'Xlink:FCXL1-1 (N-term)',
+                'Xlink:FCXL1-2 (N-term)',
             ],
             'instruments':[
                 'ESI-Q-TOF',
+                'ESI-Q-high-res',
                 'ESI-ION-TRAP-low-res',
                 'ESI-FT-ICR-CID',
                 'ESI-FT-ICR-ECD',
