@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2013 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -357,7 +357,8 @@ class panelSpectrum(wx.Panel):
         menu.Append(ID_viewSpectrumRulerDist, "Distance", "", wx.ITEM_CHECK)
         menu.Append(ID_viewSpectrumRulerPpm, "ppm", "", wx.ITEM_CHECK)
         menu.Append(ID_viewSpectrumRulerZ, "Charge", "", wx.ITEM_CHECK)
-        menu.Append(ID_viewSpectrumRulerCursorMass, "Mass", "", wx.ITEM_CHECK)
+        menu.Append(ID_viewSpectrumRulerCursorMass, "Mass (c)", "", wx.ITEM_CHECK)
+        menu.Append(ID_viewSpectrumRulerParentMass, "Mass (p)", "", wx.ITEM_CHECK)
         menu.Append(ID_viewSpectrumRulerArea, "Area", "", wx.ITEM_CHECK)
         
         # set values
@@ -365,7 +366,8 @@ class panelSpectrum(wx.Panel):
         menu.Check(ID_viewSpectrumRulerDist, bool('dist' in config.main['cursorInfo']))
         menu.Check(ID_viewSpectrumRulerPpm, bool('ppm' in config.main['cursorInfo']))
         menu.Check(ID_viewSpectrumRulerZ, bool('z' in config.main['cursorInfo']))
-        menu.Check(ID_viewSpectrumRulerCursorMass, bool('mass' in config.main['cursorInfo']))
+        menu.Check(ID_viewSpectrumRulerCursorMass, bool('cmass' in config.main['cursorInfo']))
+        menu.Check(ID_viewSpectrumRulerParentMass, bool('pmass' in config.main['cursorInfo']))
         menu.Check(ID_viewSpectrumRulerArea, bool('area' in config.main['cursorInfo']))
         
         # set events
@@ -374,6 +376,7 @@ class panelSpectrum(wx.Panel):
         self.Bind(wx.EVT_MENU, self.parent.onViewSpectrumRuler, id=ID_viewSpectrumRulerPpm)
         self.Bind(wx.EVT_MENU, self.parent.onViewSpectrumRuler, id=ID_viewSpectrumRulerZ)
         self.Bind(wx.EVT_MENU, self.parent.onViewSpectrumRuler, id=ID_viewSpectrumRulerCursorMass)
+        self.Bind(wx.EVT_MENU, self.parent.onViewSpectrumRuler, id=ID_viewSpectrumRulerParentMass)
         self.Bind(wx.EVT_MENU, self.parent.onViewSpectrumRuler, id=ID_viewSpectrumRulerArea)
         
         self.PopupMenu(menu)
