@@ -1688,8 +1688,13 @@ PyObject *list_mi2py( m_arrayi *p_inarr )
     PyObject *p_outlist, *p_inner, *p_item;
     int i, j;
     
+    // make empty list
+    if ( p_inarr == NULL ) {
+        p_outlist = PyList_New(0);
+    }
+    
     // make 1D list
-    if ( p_inarr->dim == 1 ) {
+    else if ( p_inarr->dim == 1 ) {
         p_outlist = PyList_New( p_inarr->len );
         for ( i = 0; i < p_inarr->len; ++i ) {
             p_item = PyInt_FromLong( p_inarr->data[i] );
@@ -2497,8 +2502,11 @@ static PyObject *_wrap_formula_composition( PyObject *self, PyObject *args )
     free(p_cminimum);
     free(p_cmaximum);
     free(p_cmasses);
-    free(p_mresults->data);
-    free(p_mresults);
+    
+    if ( p_mresults != NULL ) {
+        free(p_mresults->data);
+        free(p_mresults);
+    }
     
     return p_results;
 }
