@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2013 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -47,6 +47,10 @@ def formulator(mz, charge=0, tolerance=1., units='ppm', composition={}, agentFor
     else:
         mass = mz
     
+    # check neutral mass
+    if mass <= 0:
+        return []
+    
     # get mass limits
     if units == 'ppm':
         loMass = mass - (mass/1e6) * tolerance
@@ -78,7 +82,7 @@ def formulator(mz, charge=0, tolerance=1., units='ppm', composition={}, agentFor
     
     # check max composition
     for i in range(len(maxComposition)):
-        maxComposition[i] = min(maxComposition[i], int(mass/elementMasses[i]))
+        maxComposition[i] = min(maxComposition[i], int(hiMass/elementMasses[i]))
     
     # generate compositions
     formulae = []
