@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2013 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -802,9 +802,9 @@ class sequence:
                 if (strict or mod[2]=='f'):
                     if mod[1] == position \
                     or mod[1] == self.chain[position] \
-                    or mod[1] == 'nTerm' and position == 0 \
-                    or mod[1] == 'cTerm' and position == -1 \
-                    or mod[1] == 'cTerm' and position == (len(self.chain) - 1):
+                    or (mod[1] == 'nTerm' and position == 0) \
+                    or (mod[1] == 'cTerm' and position == -1) \
+                    or (mod[1] == 'cTerm' and position == (len(self.chain) - 1)):
                         return True
         
         # check whole sequence
