@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2013 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -139,12 +139,6 @@ class parseMZDATA():
         if self._scans and scanID in self._scans:
             data = self._scans[scanID]
         
-        # faster loading of single-scan documents
-        elif scanID == None:
-            parser = singleScanParser(self.path)
-            parser.parse()
-            data = parser.data
-        
         # parse file
         else:
             handler = scanHandler(scanID)
@@ -582,12 +576,12 @@ class scanHandler(xml.sax.handler.ContentHandler):
         # get mz data
         elif name == 'mzArrayBinary' and self._isMatch:
             self._isMzArray = True
-            self.data['mzData'] = ''
+            self.data['mzData'] = []
         
         # get int data
         elif name == 'intenArrayBinary' and self._isMatch:
             self._isIntArray = True
-            self.data['intData'] = ''
+            self.data['intData'] = []
         
         # get data
         elif name == 'data' and self._isMatch:
@@ -625,12 +619,16 @@ class scanHandler(xml.sax.handler.ContentHandler):
             self._isMzArray = False
             if not self.data['mzData']:
                 self.data['mzData'] = None
+            else:
+                self.data['mzData'] = ''.join(self.data['mzData'])
         
         # stop reading int data
         elif name == 'intenArrayBinary' and self._isMatch:
             self._isIntArray = False
             if not self.data['intData']:
                 self.data['intData'] = None
+            else:
+                self.data['intData'] = ''.join(self.data['intData'])
     # ----
     
     
@@ -639,11 +637,11 @@ class scanHandler(xml.sax.handler.ContentHandler):
         
         # get m/z array
         if self._isMzArray:
-            self.data['mzData'] += ch
+            self.data['mzData'].append(ch)
         
         # get intensity array
         elif self._isIntArray:
-            self.data['intData'] += ch
+            self.data['intData'].append(ch)
     # ----
     
     
@@ -765,12 +763,12 @@ class runHandler(xml.sax.handler.ContentHandler):
         # get mz data
         elif name == 'mzArrayBinary':
             self._isMzArray = True
-            self.data[self.currentID]['mzData'] = ''
+            self.data[self.currentID]['mzData'] = []
         
         # get int data
         elif name == 'intenArrayBinary':
             self._isIntArray = True
-            self.data[self.currentID]['intData'] = ''
+            self.data[self.currentID]['intData'] = []
         
         # get data
         elif name == 'data':
@@ -804,12 +802,16 @@ class runHandler(xml.sax.handler.ContentHandler):
             self._isMzArray = False
             if not self.data[self.currentID]['mzData']:
                 self.data[self.currentID]['mzData'] = None
+            else:
+                self.data[self.currentID]['mzData'] = ''.join(self.data[self.currentID]['mzData'])
         
         # stop reading int data
         elif name == 'intenArrayBinary':
             self._isIntArray = False
             if not self.data[self.currentID]['intData']:
                 self.data[self.currentID]['intData'] = None
+            else:
+                self.data[self.currentID]['intData'] = ''.join(self.data[self.currentID]['intData'])
     # ----
     
     
@@ -818,188 +820,11 @@ class runHandler(xml.sax.handler.ContentHandler):
         
         # get m/z array
         if self._isMzArray:
-            self.data[self.currentID]['mzData'] += ch
+            self.data[self.currentID]['mzData'].append(ch)
         
         # get intensity array
         elif self._isIntArray:
-            self.data[self.currentID]['intData'] += ch
-    # ----
-    
-    
-
-class singleScanParser():
-    """Faster loading of single-scan documents."""
-    
-    def __init__(self, path):
-        
-        self.path = path
-        self.data = None
-        self._parsedData = None
-    # ----
-    
-    
-    def parse(self):
-        """Parse document."""
-        
-        # read xml
-        try:
-            doc = file(self.path)
-            rawData = doc.read()
-            doc.close()
-            self._parsedData = xml.dom.minidom.parseString(rawData)
-        except:
-            self.data = None
-            return
-        
-        # init data
-        self.data = {
-                'title': '',
-                'scanNumber': None,
-                'parentScanNumber': None,
-                'msLevel': None,
-                'pointsCount': None,
-                'polarity': None,
-                'retentionTime': None,
-                'lowMZ': None,
-                'highMZ': None,
-                'basePeakMZ': None,
-                'basePeakIntensity': None,
-                'totIonCurrent': None,
-                'precursorMZ': None,
-                'precursorIntensity': None,
-                'precursorCharge': None,
-                'spectrumType': 'unknown',
-                
-                'mzData': None,
-                'mzEndian': None,
-                'mzPrecision': None,
-                'intData': None,
-                'intEndian': None,
-                'intPrecision': None,
-        }
-        
-        # parse xml
-        self.handleSpectrum()
-        self.handleMetadata()
-    # ----
-    
-    
-    def handleSpectrum(self):
-        """Get spectrum data."""
-        
-        # get spectrum type
-        acqSpecificationTags = self._parsedData.getElementsByTagName('acqSpecification')
-        if acqSpecificationTags:
-            self.data['spectrumType'] = acqSpecificationTags[0].getAttribute('spectrumType')
-        
-        # get mz data
-        mzArrayBinaryTags = self._parsedData.getElementsByTagName('mzArrayBinary')
-        if mzArrayBinaryTags:
-            dataTags = mzArrayBinaryTags[0].getElementsByTagName('data')
-            if dataTags:
-                
-                # get points count
-                attribute = dataTags[0].getAttribute('length')
-                if attribute:
-                    self.data['pointsCount'] = int(attribute)
-                
-                # get endian
-                attribute = dataTags[0].getAttribute('endian')
-                if attribute:
-                    self.data['mzEndian'] = attribute
-                
-                # get precision
-                attribute = dataTags[0].getAttribute('precision')
-                if attribute:
-                    try: self.data['mzPrecision'] = int(attribute)
-                    except ValueError: pass
-                
-                # get array data
-                self.data['mzData'] = ''
-                for node in dataTags[0].childNodes:
-                    if node.nodeType == node.TEXT_NODE:
-                        self.data['mzData'] += node.data
-        
-        # get int data
-        intenArrayBinaryTags = self._parsedData.getElementsByTagName('intenArrayBinary')
-        if intenArrayBinaryTags:
-            dataTags = intenArrayBinaryTags[0].getElementsByTagName('data')
-            if dataTags:
-                
-                # get endian
-                attribute = dataTags[0].getAttribute('endian')
-                if attribute:
-                    self.data['intEndian'] = attribute
-                
-                # get precision
-                attribute = dataTags[0].getAttribute('precision')
-                if attribute:
-                    try: self.data['intPrecision'] = int(attribute)
-                    except ValueError: pass
-                
-                # get array data
-                self.data['intData'] = ''
-                for node in dataTags[0].childNodes:
-                    if node.nodeType == node.TEXT_NODE:
-                        self.data['intData'] += node.data
-    # ----
-    
-    
-    def handleMetadata(self):
-        """Get metadata."""
-        
-        # get spectrum params
-        spectrumInstrumentTags = self._parsedData.getElementsByTagName('spectrumInstrument')
-        if spectrumInstrumentTags:
-            
-            # get ms level
-            attribute = spectrumInstrumentTags[0].getAttribute('msLevel')
-            if attribute:
-                self.data['msLevel'] = int(attribute)
-            
-            # get low m/z
-            attribute = spectrumInstrumentTags[0].getAttribute('mzRangeStart')
-            if attribute:
-                self.data['lowMZ'] = float(attribute)
-            
-            # get high m/z
-            attribute = spectrumInstrumentTags[0].getAttribute('mzRangeStop')
-            if attribute:
-                self.data['highMZ'] = float(attribute)
-        
-        # get cvParams
-        cvParamTags = self._parsedData.getElementsByTagName('cvParam')
-        for cvParamTag in cvParamTags:
-            
-            paramName = cvParamTag.getAttribute('name')
-            paramValue = cvParamTag.getAttribute('value')
-            
-            # get retention time
-            if paramName == 'TimeInMinutes' and paramValue:
-                try: self.data['retentionTime'] = float(paramValue)*60
-                except ValueError: pass
-            
-            # get total ion current
-            elif paramName == 'TotalIonCurrent' and paramValue:
-                try: self.data['totIonCurrent'] = float(paramValue)
-                except ValueError: pass
-            
-            # get precursor m/z
-            elif paramName == 'MassToChargeRatio' and paramValue:
-                try: self.data['precursorMZ'] = float(paramValue)
-                except ValueError: pass
-            
-            # get precursor charge
-            elif paramName == 'ChargeState' and paramValue:
-                try: self.data['precursorCharge'] = int(paramValue)
-                except ValueError: pass
-            
-            # get polarity
-            elif paramName == 'Polarity':
-                if paramValue in ('positive', 'Positive', '+'):
-                    self.data['polarity'] = 1
-                elif paramValue == ('negative', 'Negative', '-'):
-                    self.data['polarity'] = -1
+            self.data[self.currentID]['intData'].append(ch)
     # ----
     
     
