@@ -21,6 +21,7 @@ import xml.dom.minidom
 import base64
 import zlib
 import struct
+import re
 import os.path
 import numpy
 from copy import deepcopy
@@ -33,6 +34,9 @@ import obj_peak
 import obj_peaklist
 import obj_scan
 
+# compile basic patterns
+SCAN_NUMBER_PATTERN = re.compile('scan=([0-9]+)')
+
 
 # PARSE mzML DATA
 # ---------------
@@ -140,12 +144,6 @@ class parseMZML():
         if self._scans and scanID in self._scans:
             data = self._scans[scanID]
         
-        # faster loading of single-scan documents
-        elif scanID == None:
-            parser = singleScanParser(self.path)
-            parser.parse()
-            data = parser.data
-        
         # parse file
         else:
             handler = scanHandler(scanID)
@@ -320,17 +318,15 @@ class scanlistHandler(xml.sax.handler.ContentHandler):
             self._isSpectrum = True
             
             # get scan ID
-            self.currentID = attrs.get('index', None)
-            if self.currentID != None:
-                self.currentID = int(self.currentID)
-            
-            # add scan to hierarchy
-            self._scanHierarchy.append(self.currentID)
+            self.currentID = None
+            attribute = attrs.get('id', False)
+            if attribute:
+                self.currentID = _parseScanNumber(attribute)
             
             scan = {
                 'title': '',
                 'scanNumber': self.currentID,
-                'parentScanNumber': self._scanHierarchy[-2],
+                'parentScanNumber': None,
                 'msLevel': None,
                 'pointsCount': None,
                 'polarity': None,
@@ -357,6 +353,11 @@ class scanlistHandler(xml.sax.handler.ContentHandler):
         # precursor tag
         elif name == 'precursor' and self._isSpectrum:
             self._isPrecursor = True
+            
+            # get parent scan number
+            attribute = attrs.get('spectrumRef', False)
+            if attribute:
+                self.data[self.currentID]['parentScanNumber'] = _parseScanNumber(attribute)
         
         # get precursor
         elif name == 'cvParam' and self._isPrecursor:
@@ -423,12 +424,9 @@ class scanlistHandler(xml.sax.handler.ContentHandler):
     def endElement(self, name):
         """Element ended."""
         
-        # remove scan from hierarchy
+        # end spectrum element
         if name == 'spectrum':
-            del self._scanHierarchy[-1]
-            self.currentID = self._scanHierarchy[-1]
-            if self._scanHierarchy == [None]:
-                self._isSpectrum = False
+            self._isSpectrum = False
         
         # end precursor element
         elif name == 'precursor':
@@ -471,12 +469,10 @@ class scanHandler(xml.sax.handler.ContentHandler):
             self._isMatch = False
             
             # get scan ID
-            scanID = attrs.get('index', None)
-            if scanID != None:
-                scanID = int(scanID)
-            
-            # add scan to hierarchy
-            self._scanHierarchy.append(scanID)
+            scanID = None
+            attribute = attrs.get('id', False)
+            if attribute:
+                scanID = _parseScanNumber(attribute)
             
             # selected scan
             if self.scanID == None or self.scanID == scanID:
@@ -485,7 +481,7 @@ class scanHandler(xml.sax.handler.ContentHandler):
                 self.data = {
                     'title': '',
                     'scanNumber': scanID,
-                    'parentScanNumber': self._scanHierarchy[-2],
+                    'parentScanNumber': None,
                     'msLevel': None,
                     'pointsCount': None,
                     'polarity': None,
@@ -516,11 +512,16 @@ class scanHandler(xml.sax.handler.ContentHandler):
         # precursor tag
         elif name == 'precursor' and self._isMatch:
             self._isPrecursor = True
+            
+            # get parent scan number
+            attribute = attrs.get('spectrumRef', False)
+            if attribute:
+                self.data['parentScanNumber'] = _parseScanNumber(attribute)
         
         # binary aray tag
         elif name == 'binaryDataArray' and self._isMatch:
             self._isBinaryDataArray = True
-            self.tmpBinaryData = ''
+            self.tmpBinaryData = []
             self.tmpPrecision = None
             self.tmpCompression = None
             self.tmpArrayType = None
@@ -621,11 +622,9 @@ class scanHandler(xml.sax.handler.ContentHandler):
         if name == 'spectrum' and self._isMatch:
             raise stopParsing()
         
-        # remove scan from hierarchy
+        # end spectrum element
         elif name == 'spectrum':
-            del self._scanHierarchy[-1]
-            if self._scanHierarchy[-1] == self.scanID:
-                self._isMatch = True
+            self._isMatch = False
         
         # end precursor element
         elif name == 'precursor' and self._isMatch:
@@ -637,13 +636,13 @@ class scanHandler(xml.sax.handler.ContentHandler):
             
             # mz array
             if self.tmpArrayType == 'mzArray':
-                self.data['mzData'] = self.tmpBinaryData
+                self.data['mzData'] = ''.join(self.tmpBinaryData)
                 self.data['mzPrecision'] = self.tmpPrecision
                 self.data['mzCompression'] = self.tmpCompression
             
             # intensity array
             elif self.tmpArrayType == 'intArray':
-                self.data['intData'] = self.tmpBinaryData
+                self.data['intData'] = ''.join(self.tmpBinaryData)
                 self.data['intPrecision'] = self.tmpPrecision
                 self.data['intCompression'] = self.tmpCompression
             
@@ -662,7 +661,7 @@ class scanHandler(xml.sax.handler.ContentHandler):
         
         # get peaks
         if self._isData:
-            self.tmpBinaryData += ch
+            self.tmpBinaryData.append(ch)
     # ----
     
     
@@ -678,7 +677,6 @@ class runHandler(xml.sax.handler.ContentHandler):
         self._isPrecursor = False
         self._isBinaryDataArray = False
         self._isData = False
-        self._scanHierarchy = [None]
         
         self.tmpBinaryData = None
         self.tmpPrecision = None
@@ -695,17 +693,15 @@ class runHandler(xml.sax.handler.ContentHandler):
             self._isSpectrum = True
             
             # get scan ID
-            self.currentID = attrs.get('index', None)
-            if self.currentID != None:
-                self.currentID = int(self.currentID)
-            
-            # add scan to hierarchy
-            self._scanHierarchy.append(self.currentID)
+            self.currentID = None
+            attribute = attrs.get('id', False)
+            if attribute:
+                self.currentID = _parseScanNumber(attribute)
             
             scan = {
                 'title': '',
                 'scanNumber': self.currentID,
-                'parentScanNumber': self._scanHierarchy[-2],
+                'parentScanNumber': None,
                 'msLevel': None,
                 'pointsCount': None,
                 'polarity': None,
@@ -739,11 +735,16 @@ class runHandler(xml.sax.handler.ContentHandler):
         # precursor tag
         elif name == 'precursor' and self._isSpectrum:
             self._isPrecursor = True
+            
+            # get parent scan number
+            attribute = attrs.get('spectrumRef', False)
+            if attribute:
+                self.data[self.currentID]['parentScanNumber'] = _parseScanNumber(attribute)
         
         # binary aray tag
         elif name == 'binaryDataArray' and self._isSpectrum:
             self._isBinaryDataArray = True
-            self.tmpBinaryData = ''
+            self.tmpBinaryData = []
             self.tmpPrecision = None
             self.tmpCompression = None
             self.tmpArrayType = None
@@ -840,12 +841,9 @@ class runHandler(xml.sax.handler.ContentHandler):
     def endElement(self, name):
         """Element ended."""
         
-        # remove scan from hierarchy
+        # end spectrum element
         if name == 'spectrum':
-            del self._scanHierarchy[-1]
-            self.currentID = self._scanHierarchy[-1]
-            if self._scanHierarchy == [None]:
-                self._isSpectrum = False
+            self._isSpectrum = False
         
         # end precursor element
         elif name == 'precursor':
@@ -857,13 +855,13 @@ class runHandler(xml.sax.handler.ContentHandler):
             
             # mz array
             if self.tmpArrayType == 'mzArray':
-                self.data[self.currentID]['mzData'] = self.tmpBinaryData
+                self.data[self.currentID]['mzData'] = ''.join(self.tmpBinaryData)
                 self.data[self.currentID]['mzPrecision'] = self.tmpPrecision
                 self.data[self.currentID]['mzCompression'] = self.tmpCompression
             
             # intensity array
             elif self.tmpArrayType == 'intArray':
-                self.data[self.currentID]['intData'] = self.tmpBinaryData
+                self.data[self.currentID]['intData'] = ''.join(self.tmpBinaryData)
                 self.data[self.currentID]['intPrecision'] = self.tmpPrecision
                 self.data[self.currentID]['intCompression'] = self.tmpCompression
             
@@ -882,175 +880,7 @@ class runHandler(xml.sax.handler.ContentHandler):
         
         # get peaks
         if self._isData:
-            self.tmpBinaryData += ch
-    # ----
-    
-    
-
-class singleScanParser():
-    """Faster loading of single-scan documents."""
-    
-    def __init__(self, path):
-        
-        self.path = path
-        self.data = None
-        self._parsedData = None
-    # ----
-    
-    
-    def parse(self):
-        """Parse document."""
-        
-        # read xml
-        try:
-            doc = file(self.path)
-            rawData = doc.read()
-            doc.close()
-            self._parsedData = xml.dom.minidom.parseString(rawData)
-        except:
-            self.data = None
-            return
-        
-        # init data
-        self.data = {
-                'title': '',
-                'scanNumber': None,
-                'parentScanNumber': None,
-                'msLevel': None,
-                'pointsCount': None,
-                'polarity': None,
-                'retentionTime': None,
-                'lowMZ': None,
-                'highMZ': None,
-                'basePeakMZ': None,
-                'basePeakIntensity': None,
-                'totIonCurrent': None,
-                'precursorMZ': None,
-                'precursorIntensity': None,
-                'precursorCharge': None,
-                'spectrumType': 'unknown',
-                
-                'mzData': None,
-                'mzPrecision': None,
-                'mzCompression': None,
-                'intData': None,
-                'intPrecision': None,
-                'intCompression': None,
-        }
-        
-        # parse xml
-        self.handleSpectrum()
-        self.handleMetadata()
-    # ----
-    
-    
-    def handleSpectrum(self):
-        """Get spectrum data."""
-        
-        # get spectrum type
-        cvParamTags = self._parsedData.getElementsByTagName('cvParam')
-        for cvParamTag in cvParamTags:
-            if cvParamTag.getAttribute('name') == 'centroid spectrum':
-                self.data['spectrumType'] = 'discrete'
-            elif cvParamTag.getAttribute('name') == 'profile spectrum':
-                self.data['spectrumType'] = 'continuous'
-        
-        # get data
-        for binaryDataArrayTag in self._parsedData.getElementsByTagName('binaryDataArray'):
-                
-                tmpdata = {
-                    'dataType': '',
-                    'binaryData': '',
-                    'compression': None,
-                    'precision': 32,
-                }
-                
-                # get data
-                binary = binaryDataArrayTag.getElementsByTagName('binary')
-                for node in binary[0].childNodes:
-                    if node.nodeType == node.TEXT_NODE:
-                        tmpdata['binaryData'] += node.data
-                
-                # get params
-                for cvParamTag in binaryDataArrayTag.getElementsByTagName('cvParam'):
-                    if cvParamTag.getAttribute('name') == 'zlib compression':
-                        tmpdata['compression'] = 'zlib'
-                    if cvParamTag.getAttribute('name') == '64-bit float':
-                        tmpdata['precision'] = 64
-                    if cvParamTag.getAttribute('name') == '32-bit float':
-                        tmpdata['precision'] = 32
-                    if cvParamTag.getAttribute('name') == 'm/z array':
-                        tmpdata['dataType'] = 'm/z array'
-                    if cvParamTag.getAttribute('name') == 'intensity array':
-                        tmpdata['dataType'] = 'intensity array'
-                
-                # store data
-                if tmpdata['dataType'] == 'm/z array':
-                    self.data['mzData'] = tmpdata['binaryData']
-                    self.data['mzPrecision'] = tmpdata['precision']
-                    self.data['mzCompression'] = tmpdata['compression']
-                
-                elif tmpdata['dataType'] == 'intensity array':
-                    self.data['intData'] = tmpdata['binaryData']
-                    self.data['intPrecision'] = tmpdata['precision']
-                    self.data['intCompression'] = tmpdata['compression']
-    # ----
-    
-    
-    def handleMetadata(self):
-        """Get metadata."""
-        
-        # get cvParams
-        cvParamTags = self._parsedData.getElementsByTagName('cvParam')
-        for cvParamTag in cvParamTags:
-            
-            paramName = cvParamTag.getAttribute('name')
-            paramValue = cvParamTag.getAttribute('value')
-            
-            # precursor
-            if paramName == 'selected ion m/z' and paramValue:
-                self.data['precursorMZ'] = float(paramValue)
-            elif paramName == 'intensity' and paramValue:
-                self.data['precursorIntensity'] = float(paramValue)
-            elif paramName == 'possible charge state' and paramValue:
-                self.data['precursorCharge'] = int(paramValue)
-            elif paramName == 'charge state' and paramValue:
-                self.data['precursorCharge'] = int(paramValue)
-            
-            # MS level
-            elif paramName == 'ms level' and paramValue:
-                self.data['msLevel'] = int(paramValue)
-            
-            # polarity
-            elif paramName == 'positive scan':
-                self.data['polarity'] = 1
-            elif paramName == 'negative scan':
-                self.data['polarity'] = -1
-            
-            # total ion current
-            elif paramName == 'total ion current' and paramValue:
-                self.data['totIonCurrent'] = max(0.0, float(paramValue))
-            
-            # base peak
-            elif paramName == 'base peak m/z' and paramValue:
-                self.data['basePeakMZ'] = float(paramValue)
-            elif paramName == 'base peak intensity' and paramValue:
-                self.data['basePeakIntensity'] = max(0.0, float(paramValue))
-            
-            # mass range
-            elif paramName == 'lowest observed m/z' and paramValue:
-                self.data['lowMZ'] = float(paramValue)
-            elif paramName == 'highest observed m/z' and paramValue:
-                self.data['highMZ'] = float(paramValue)
-            
-            # retention time
-            elif paramName == 'scan start time' and paramValue:
-                if cvParamTag.getAttribute('unitName') == 'minute':
-                    self.data['retentionTime'] = float(paramValue)*60
-                elif cvParamTag.getAttribute('unitName') == 'second':
-                    self.data['retentionTime'] = float(paramValue)
-                else:
-                    self.data['retentionTime'] = float(paramValue)*60
+            self.tmpBinaryData.append(ch)
     # ----
     
     
@@ -1058,3 +888,18 @@ class singleScanParser():
 class stopParsing(Exception):
     """Exeption to stop parsing XML data."""
     pass
+
+
+def _parseScanNumber(string):
+    """Parse real scan number from id tag."""
+    
+    # match scan number pattern
+    match = SCAN_NUMBER_PATTERN.search(string)
+    if not match:
+        return None
+    
+    # convert to int
+    try: return int(match.group(1))
+    except: return None
+# ----
+
