@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2013 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ import obj_peaklist
 import obj_scan
 
 # compile basic patterns
-retentionPattern = re.compile('^PT((\d*\.?\d*)M)?((\d*\.?\d*)S)?$')
+RETENTION_TIME_PATTERN = re.compile('^PT((\d*\.?\d*)M)?((\d*\.?\d*)S)?$')
 
 
 # PARSE mzXML DATA
@@ -142,12 +142,6 @@ class parseMZXML():
         if self._scans and scanID in self._scans:
             data = self._scans[scanID]
         
-        # faster loading of single-scan documents
-        elif scanID == None:
-            parser = singleScanParser(self.path)
-            parser.parse()
-            data = parser.data
-        
         # parse file
         else:
             handler = scanHandler(scanID)
@@ -549,7 +543,7 @@ class scanHandler(xml.sax.handler.ContentHandler):
         # get peaks data
         elif name == 'peaks' and self._isMatch:
             self._isPeaks = True
-            self.data['points'] = ''
+            self.data['points'] = []
             
             # get byte order
             self.data['byteOrder'] = attrs.get('byteOrder','network')
@@ -597,6 +591,7 @@ class scanHandler(xml.sax.handler.ContentHandler):
         # stop reading peaks data
         elif name == 'peaks' and self._isMatch:
             self._isPeaks = False
+            self.data['points'] = ''.join(self.data['points'])
             if not self.data['points']:
                 self.data['points'] = None
         
@@ -617,7 +612,7 @@ class scanHandler(xml.sax.handler.ContentHandler):
         
         # get peaks
         if self._isPeaks:
-            self.data['points'] += ch
+            self.data['points'].append(ch)
         
         # get precursor
         if self._isPrecursor:
@@ -737,7 +732,7 @@ class runHandler(xml.sax.handler.ContentHandler):
         # get peaks data
         elif name == 'peaks':
             self._isPeaks = True
-            self.data[self.currentID]['points'] = ''
+            self.data[self.currentID]['points'] = []
             
             # get byte order
             self.data[self.currentID]['byteOrder'] = attrs.get('byteOrder','network')
@@ -780,8 +775,9 @@ class runHandler(xml.sax.handler.ContentHandler):
         # stop reading peaks data
         elif name == 'peaks':
             self._isPeaks = False
+            self.data[self.currentID]['points'] = ''.join(self.data[self.currentID]['points'])
             if not self.data[self.currentID]:
-                self.data[self.currentID] = None
+                self.data[self.currentID]['points'] = None
         
         # stop reading precursor data
         elif name == 'precursorMz':
@@ -800,7 +796,7 @@ class runHandler(xml.sax.handler.ContentHandler):
         
         # get peaks
         if self._isPeaks:
-            self.data[self.currentID]['points'] += ch
+            self.data[self.currentID]['points'].append(ch)
         
         # get precursor mz
         if self._isPrecursor:
@@ -809,175 +805,6 @@ class runHandler(xml.sax.handler.ContentHandler):
     
     
 
-class singleScanParser():
-    """Faster loading of single-scan documents."""
-    
-    def __init__(self, path):
-        
-        self.path = path
-        self.data = None
-        self._parsedData = None
-    # ----
-    
-    
-    def parse(self):
-        """Parse document."""
-        
-        # read xml
-        try:
-            doc = file(self.path)
-            rawData = doc.read()
-            doc.close()
-            self._parsedData = xml.dom.minidom.parseString(rawData)
-        except:
-            self.data = None
-            return
-        
-        # init data
-        self.data = {
-                'title': '',
-                'scanNumber': None,
-                'parentScanNumber': None,
-                'msLevel': None,
-                'pointsCount': None,
-                'polarity': None,
-                'retentionTime': None,
-                'lowMZ': None,
-                'highMZ': None,
-                'basePeakMZ': None,
-                'basePeakIntensity': None,
-                'totIonCurrent': None,
-                'precursorMZ': None,
-                'precursorIntensity': None,
-                'precursorCharge': None,
-                'spectrumType': 'unknown',
-                
-                'points': None,
-                'byteOrder': None,
-                'compression': None,
-                'precision': None,
-        }
-        
-        # parse xml
-        self.handleSpectrum()
-        self.handleMetadata()
-    # ----
-    
-    
-    def handleSpectrum(self):
-        """Get spectrum data."""
-        
-        # get data type
-        dataProcessingTags = self._parsedData.getElementsByTagName('dataProcessing')
-        if dataProcessingTags:
-            centroided = dataProcessingTags[0].getAttribute('centroided')
-            if centroided and centroided != '0':
-                self.data['spectrumType'] = 'discrete'
-        
-        # get data
-        peaksTags = self._parsedData.getElementsByTagName('peaks')
-        if peaksTags:
-            
-            # get byte order
-            self.data['byteOrder'] = peaksTags[0].getAttribute('byteOrder')
-            
-            # get compression
-            attribute = peaksTags[0].getAttribute('compressionType')
-            if attribute and attribute != 'none':
-                self.data['compression'] = attribute
-            
-            # get precision
-            attribute = peaksTags[0].getAttribute('precision')
-            if attribute:
-                self.data['precision'] = int(attribute)
-            
-            # get array data
-            self.data['points'] = ''
-            for node in peaksTags[0].childNodes:
-                if node.nodeType == node.TEXT_NODE:
-                    self.data['points'] += node.data
-    # ----
-    
-    
-    def handleMetadata(self):
-        """Get metadata."""
-        
-        # get scan meta
-        scanTags = self._parsedData.getElementsByTagName('scan')
-        if scanTags:
-            
-            # get ms level
-            attribute = scanTags[0].getAttribute('msLevel')
-            if attribute:
-                self.data['msLevel'] = int(attribute)
-            
-            # get number of points
-            attribute = scanTags[0].getAttribute('peaksCount')
-            if attribute:
-                self.data['pointsCount'] = int(attribute)
-            
-            # get polarity
-            attribute = scanTags[0].getAttribute('polarity')
-            if attribute in ('positive', 'Positive', '+'):
-                self.data['polarity'] = 1
-            elif attribute in ('negative', 'Negative', '-'):
-                self.data['polarity'] = -1
-            
-            # get scan retention time
-            attribute = scanTags[0].getAttribute('retentionTime')
-            if attribute:
-                self.data['retentionTime'] = _convertRetentionTime(attribute)
-            
-            # get low m/z
-            attribute = scanTags[0].getAttribute('lowMz')
-            if attribute:
-                self.data['lowMZ'] = float(attribute)
-            
-            # get high m/z
-            attribute = scanTags[0].getAttribute('highMz')
-            if attribute:
-                self.data['highMZ'] = float(attribute)
-            
-            # get base peak m/z
-            attribute = scanTags[0].getAttribute('basePeakMz')
-            if attribute:
-                self.data['basePeakMZ'] = float(attribute)
-            
-            # get base peak intensity
-            attribute = scanTags[0].getAttribute('basePeakIntensity')
-            if attribute:
-                self.data['basePeakIntensity'] = max(0.0, float(attribute))
-            
-            # get total ion current
-            attribute = scanTags[0].getAttribute('totIonCurrent')
-            if attribute:
-                self.data['totIonCurrent'] = max(0.0, float(attribute))
-        
-        # get precursor
-        precursorMzTags = self._parsedData.getElementsByTagName('precursorMz')
-        if precursorMzTags:
-            
-            # get precursor intensity
-            attribute = precursorMzTags[0].getAttribute('precursorIntensity')
-            if attribute:
-                self.data['precursorIntensity'] = max(0.0, float(attribute))
-            
-            # get precursor charge
-            attribute = precursorMzTags[0].getAttribute('precursorCharge')
-            if attribute:
-                self.data['precursorCharge'] = int(attribute)
-            
-            # get precursor m/z
-            precursorMZ = ''
-            for node in precursorMzTags[0].childNodes:
-                if node.nodeType == node.TEXT_NODE:
-                    precursorMZ += node.data
-            if precursorMZ:
-                self.data['precursorMZ'] = float(precursorMZ)
-    # ----
-    
-    
-
 class stopParsing(Exception):
     """Exeption to stop parsing XML data."""
     pass
@@ -987,7 +814,7 @@ def _convertRetentionTime(retention):
     """Convert retention time to seconds."""
     
     # match retention
-    match = retentionPattern.match(retention)
+    match = RETENTION_TIME_PATTERN.match(retention)
     if not match:
         return None
     
