@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2013 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -265,12 +265,19 @@ class canvas(wx.Window):
             # clear zoombox
             self.drawZoomBox()
             
-            # get X axis
+            # get zoom
             minX = min(self.draggingStart[0], self.cursorPosition[0])
             maxX = max(self.draggingStart[0], self.cursorPosition[0])
+            minY = min(self.draggingStart[1], self.cursorPosition[1])
+            maxY = max(self.draggingStart[1], self.cursorPosition[1])
             
-            # zoom plot
-            self.zoom((minX, maxX))
+            # apply zoom
+            if self.properties['zoomAxis'] == 'xy' and minX != maxX and minY != maxY:
+                self.zoom(xAxis=(minX, maxX), yAxis=(minY, maxY))
+            elif self.properties['zoomAxis'] == 'x' and minX != maxX:
+                self.zoom(xAxis=(minX, maxX))
+            elif self.properties['zoomAxis'] == 'y' and minY != maxY:
+                self.zoom(yAxis=(minY, maxY))
         
         # clear point selection
         elif self.mouseEvent == 'point':
@@ -352,7 +359,7 @@ class canvas(wx.Window):
         # get focus
         if not self.FindFocus() == self:
             self.SetFocus()
-            
+        
         # get cursor positions
         self.cursorPosition[0], self.cursorPosition[1] = self.getXY(evt)
         self.cursorPosition[2], self.cursorPosition[3] = evt.GetPosition()
@@ -398,13 +405,13 @@ class canvas(wx.Window):
             # clear zoombox
             self.drawZoomBox()
             
-            # get X axis
+            # get zoom
             minX = min(self.draggingStart[0], self.cursorPosition[0])
             maxX = max(self.draggingStart[0], self.cursorPosition[0])
             minY = min(self.draggingStart[1], self.cursorPosition[1])
             maxY = max(self.draggingStart[1], self.cursorPosition[1])
             
-            # zoom plot
+            # apply zoom
             if self.properties['zoomAxis'] == 'xy' and minX != maxX and minY != maxY:
                 self.zoom(xAxis=(minX, maxX), yAxis=(minY, maxY))
             elif self.properties['zoomAxis'] == 'x' and minX != maxX:
@@ -1073,7 +1080,6 @@ class canvas(wx.Window):
             dc = wx.BufferedDC(wx.ClientDC(self), self.plotBuffer)
         dc.SetBackground(wx.Brush(self.properties['canvasColour'], wx.SOLID))
         dc.Clear()
-        dc.BeginDrawing()
         
         # set dc font
         dc.SetFont(_scaleFont(self.properties['axisFont'], self.printerScale['fonts']))
@@ -1173,8 +1179,6 @@ class canvas(wx.Window):
         # draw legend
         if self.properties['showLegend']:
             self.drawLegend(dc, graphics)
-        
-        dc.EndDrawing()
     # ----
     
     
@@ -1202,6 +1206,8 @@ class canvas(wx.Window):
         plotX2 += penWidth
         plotY2 += penWidth
         
+        dc.BeginDrawing()
+        
         # fill background
         dc.SetBrush(wx.Brush(self.properties['plotColour'], wx.SOLID))
         dc.DrawRectangle(plotX1, plotY1, plotX2 - plotX1, plotY2 - plotY1)
@@ -1268,6 +1274,8 @@ class canvas(wx.Window):
         
         # draw plot outline
         dc.DrawRectangle(plotX1, plotY1, plotX2 - plotX1, plotY2 - plotY1)
+        
+        dc.EndDrawing()
     # ----
     
     
@@ -1280,6 +1288,8 @@ class canvas(wx.Window):
         # set font
         dc.SetFont(_scaleFont(self.properties['axisFont'], self.printerScale['fonts']))
         
+        dc.BeginDrawing()
+        
         # draw legend
         y = self.plotCoords[1] + 5 * self.printerScale['drawings']
         for name in names:
@@ -1303,16 +1313,14 @@ class canvas(wx.Window):
             
             # set y for next name
             y += dc.GetTextExtent(name[0])[1]/2 + 2 * self.printerScale['drawings']
+        
+        dc.EndDrawing()
     # ----
     
     
     def drawXPositionBar(self, dc, xAxis):
         """Draw position bar."""
         
-        # set pen
-        penWidth = self.printerScale['drawings']
-        dc.SetPen(wx.Pen(self.properties['axisColour'], penWidth))
-        
         # get plot coordinates
         x1, y1, x2, y2 = self.plotCoords
         x1 -= self.printerScale['drawings']
@@ -1336,6 +1344,12 @@ class canvas(wx.Window):
         if currWidth < 0:
             currWidth = 0
         
+        # set pen
+        penWidth = self.printerScale['drawings']
+        dc.SetPen(wx.Pen(self.properties['axisColour'], penWidth))
+        
+        dc.BeginDrawing()
+        
         # draw outline
         dc.SetBrush(wx.Brush(self.properties['plotColour'], wx.SOLID))
         dc.DrawRectangle(x1, y1, width, height)
@@ -1354,16 +1368,14 @@ class canvas(wx.Window):
         if xAxis[0] > maxX:
             x = x2 + 2*self.printerScale['drawings']
             dc.DrawPolygon([(x, y1), (x, y1+height), (x+size, y1+height/2)])
+        
+        dc.EndDrawing()
     # ----
     
     
     def drawYPositionBar(self, dc, yAxis):
         """Draw position bar."""
         
-        # set pen
-        penWidth = self.printerScale['drawings']
-        dc.SetPen(wx.Pen(self.properties['axisColour'], penWidth))
-        
         # get plot coordinates
         x1, y1, x2, y2 = self.plotCoords
         x1 = x2 + (5 + 2) * self.printerScale['drawings']
@@ -1390,6 +1402,12 @@ class canvas(wx.Window):
         if y+currHeight < y1:
             currHeight = 0
         
+        # set pen
+        penWidth = self.printerScale['drawings']
+        dc.SetPen(wx.Pen(self.properties['axisColour'], penWidth))
+        
+        dc.BeginDrawing()
+        
         # draw outline
         dc.SetBrush(wx.Brush(self.properties['plotColour'], wx.SOLID))
         dc.DrawRectangle(x1, y1, width, height)
@@ -1408,6 +1426,8 @@ class canvas(wx.Window):
         if yAxis[1] < minY:
             y = y2 + 2*self.printerScale['drawings']
             dc.DrawPolygon([(x1, y), (x1+width, y), (x1+width/2, y+size)])
+        
+        dc.EndDrawing()
     # ----
     
     
@@ -1798,47 +1818,6 @@ class canvas(wx.Window):
     # ----
     
     
-    def drawZoomBox_(self):
-        """Draw zoom-box"""
-        
-        # get coordinations
-        minX = self.draggingStart[2]
-        maxX = self.cursorPosition[2]
-        minYPlot = self.plotCoords[1]
-        maxYPlot = self.plotCoords[3]
-        
-        # get gel coords
-        if self.properties['showGel']:
-            minYGel = minYPlot - (8 * self.printerScale['drawings'])
-            maxYGel = minYGel - self.gelsCount * self.properties['gelHeight']
-        
-        # check stop position limits
-        if maxX < self.plotCoords[0]:
-            maxX = self.plotCoords[0]
-        elif maxX > self.plotCoords[2]:
-            maxX = self.plotCoords[2]
-        
-        # draw zoombox
-        dc = wx.ClientDC(self)
-        dc.BeginDrawing()
-        dc.SetPen(wx.Pen(wx.BLACK))
-        dc.SetBrush(wx.Brush(wx.WHITE, wx.SOLID))
-        dc.SetLogicalFunction(wx.INVERT)
-        if minX == maxX:
-            dc.DrawLine(minX, minYPlot, maxX, maxYPlot)
-            if self.properties['showGel']:
-                dc.DrawLine(minX, minYGel, maxX, maxYGel)
-        else:
-            dc.DrawRectangle(minX, maxYPlot, maxX - minX, minYPlot - maxYPlot)
-            if self.properties['showGel']:
-                minYGel += self.printerScale['drawings']
-                maxYGel -= self.printerScale['drawings']
-                dc.DrawRectangle(minX, maxYGel, maxX - minX, minYGel-maxYGel)
-        dc.SetLogicalFunction(wx.COPY)
-        dc.EndDrawing()
-    # ----
-    
-    
     def drawZoomBox(self):
         """Draw zoom-box"""
         
