@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2013 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -362,6 +362,11 @@ class annotations:
     
     def setNormalization(self, value):
         """Force specified normalization to be used insted of calculated one."""
+        
+        value = float(value)
+        if value == 0.0:
+            value = 1.0
+        
         self.normalization = value
     # ----
     
@@ -571,17 +576,18 @@ class annotations:
     def _normalization(self):
         """Calculate normalization constants."""
         
-        self.normalization = 1.0
+        normalization = 1.0
         
-        # check data
-        if not len(self.points):
-            return
+        # calc normalization
+        if len(self.points):
+            normalization = self.pointsBox[1][1] / 100.
         
-        # get range
-        minXY, maxXY = self.pointsBox
+        # check value
+        if normalization == 0.0:
+            normalization = 1.0
         
-        # set normalization
-        self.normalization = maxXY[1] / 100.
+        # set value
+        self.normalization = normalization
     # ----
     
 
@@ -644,6 +650,11 @@ class points:
     
     def setNormalization(self, value):
         """Force specified normalization to be used insted of calculated one."""
+        
+        value = float(value)
+        if value == 0.0:
+            value = 1.0
+        
         self.normalization = value
     # ----
     
@@ -837,17 +848,18 @@ class points:
     def _normalization(self):
         """Calculate normalization constants."""
         
-        self.normalization = 1.0
+        normalization = 1.0
         
-        # check data
-        if not len(self.points):
-            return
+        # calc normalization
+        if len(self.points):
+            normalization = self.pointsBox[1][1] / 100.
         
-        # get range
-        minXY, maxXY = self.pointsBox
+        # check value
+        if normalization == 0.0:
+            normalization = 1.0
         
-        # set normalization
-        self.normalization = maxXY[1] / 100.
+        # set value
+        self.normalization = normalization
     # ----
     
 
@@ -931,6 +943,11 @@ class spectrum:
     
     def setNormalization(self, value):
         """Force specified normalization to be used insted of calculated one."""
+        
+        value = float(value)
+        if value == 0.0:
+            value = 1.0
+        
         self.normalization = value
     # ----
     
@@ -1509,21 +1526,30 @@ class spectrum:
     def _normalization(self):
         """Calculate normalization constants."""
         
+        normalization = 0.0
+        
         # get range from points and peaklist
         if len(self.spectrumPoints) and len(self.peaklistPoints):
             spectrumMinXY, spectrumMaxXY = self.spectrumBox
             peaklistMinXY, peaklistMaxXY = self.peaklistBox
-            self.normalization = max(spectrumMaxXY[1], peaklistMaxXY[1]) / 100.
+            normalization = max(spectrumMaxXY[1], peaklistMaxXY[1]) / 100.
         
         # get range from points only
         elif len(self.spectrumPoints):
             minXY, maxXY = self.spectrumBox
-            self.normalization = maxXY[1] / 100.
+            normalization = maxXY[1] / 100.
         
         # get range from peaklist only
         elif len(self.peaklistPoints):
             minXY, maxXY = self.peaklistBox
-            self.normalization = maxXY[1] / 100.
+            normalization = maxXY[1] / 100.
+        
+        # check value
+        if normalization == 0.0:
+            normalization = 1.0
+        
+        # set value
+        self.normalization = normalization
     # ----
     
     
